@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,12 +13,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from .annotation import Annotation
-from .annotation_spec import AnnotationSpec
-from .artifact import Artifact
-from .batch_prediction_job import BatchPredictionJob
-from .completion_stats import CompletionStats
-from .context import Context
+from .annotation import (
+    Annotation,
+)
+from .annotation_spec import (
+    AnnotationSpec,
+)
+from .artifact import (
+    Artifact,
+)
+from .batch_prediction_job import (
+    BatchPredictionJob,
+)
+from .completion_stats import (
+    CompletionStats,
+)
+from .context import (
+    Context,
+)
 from .custom_job import (
     ContainerSpec,
     CustomJob,
@@ -27,7 +39,9 @@ from .custom_job import (
     Scheduling,
     WorkerPoolSpec,
 )
-from .data_item import DataItem
+from .data_item import (
+    DataItem,
+)
 from .data_labeling_job import (
     ActiveLearningConfig,
     DataLabelingJob,
@@ -59,12 +73,19 @@ from .dataset_service import (
     ListDatasetsResponse,
     UpdateDatasetRequest,
 )
-from .deployed_index_ref import DeployedIndexRef
-from .deployed_model_ref import DeployedModelRef
-from .encryption_spec import EncryptionSpec
+from .deployed_index_ref import (
+    DeployedIndexRef,
+)
+from .deployed_model_ref import (
+    DeployedModelRef,
+)
+from .encryption_spec import (
+    EncryptionSpec,
+)
 from .endpoint import (
     DeployedModel,
     Endpoint,
+    PredictRequestResponseLoggingConfig,
     PrivateEndpoints,
 )
 from .endpoint_service import (
@@ -82,10 +103,18 @@ from .endpoint_service import (
     UndeployModelResponse,
     UpdateEndpointRequest,
 )
-from .entity_type import EntityType
-from .env_var import EnvVar
-from .event import Event
-from .execution import Execution
+from .entity_type import (
+    EntityType,
+)
+from .env_var import (
+    EnvVar,
+)
+from .event import (
+    Event,
+)
+from .execution import (
+    Execution,
+)
 from .explanation import (
     Attribution,
     BlurBaselineConfig,
@@ -101,14 +130,25 @@ from .explanation import (
     SmoothGradConfig,
     XraiAttribution,
 )
-from .explanation_metadata import ExplanationMetadata
-from .feature import Feature
-from .feature_monitoring_stats import FeatureStatsAnomaly
+from .explanation_metadata import (
+    ExplanationMetadata,
+)
+from .feature import (
+    Feature,
+)
+from .feature_monitoring_stats import (
+    FeatureStatsAnomaly,
+)
 from .feature_selector import (
     FeatureSelector,
     IdMatcher,
 )
-from .featurestore import Featurestore
+from .featurestore import (
+    Featurestore,
+)
+from .featurestore_monitoring import (
+    FeaturestoreMonitoringConfig,
+)
 from .featurestore_online_service import (
     FeatureValue,
     FeatureValueList,
@@ -156,8 +196,12 @@ from .featurestore_service import (
     UpdateFeaturestoreOperationMetadata,
     UpdateFeaturestoreRequest,
 )
-from .hyperparameter_tuning_job import HyperparameterTuningJob
-from .index import Index
+from .hyperparameter_tuning_job import (
+    HyperparameterTuningJob,
+)
+from .index import (
+    Index,
+)
 from .index_endpoint import (
     DeployedIndex,
     DeployedIndexAuthConfig,
@@ -241,7 +285,9 @@ from .job_service import (
     UpdateModelDeploymentMonitoringJobOperationMetadata,
     UpdateModelDeploymentMonitoringJobRequest,
 )
-from .lineage_subgraph import LineageSubgraph
+from .lineage_subgraph import (
+    LineageSubgraph,
+)
 from .machine_resources import (
     AutomaticResources,
     AutoscalingMetricSpec,
@@ -249,10 +295,15 @@ from .machine_resources import (
     DedicatedResources,
     DiskSpec,
     MachineSpec,
+    NfsMount,
     ResourcesConsumed,
 )
-from .manual_batch_tuning_parameters import ManualBatchTuningParameters
-from .metadata_schema import MetadataSchema
+from .manual_batch_tuning_parameters import (
+    ManualBatchTuningParameters,
+)
+from .metadata_schema import (
+    MetadataSchema,
+)
 from .metadata_service import (
     AddContextArtifactsAndExecutionsRequest,
     AddContextArtifactsAndExecutionsResponse,
@@ -302,8 +353,12 @@ from .metadata_service import (
     UpdateContextRequest,
     UpdateExecutionRequest,
 )
-from .metadata_store import MetadataStore
-from .migratable_resource import MigratableResource
+from .metadata_store import (
+    MetadataStore,
+)
+from .migratable_resource import (
+    MigratableResource,
+)
 from .migration_service import (
     BatchMigrateResourcesOperationMetadata,
     BatchMigrateResourcesRequest,
@@ -327,8 +382,12 @@ from .model_deployment_monitoring_job import (
     ModelMonitoringStatsAnomalies,
     ModelDeploymentMonitoringObjectiveType,
 )
-from .model_evaluation import ModelEvaluation
-from .model_evaluation_slice import ModelEvaluationSlice
+from .model_evaluation import (
+    ModelEvaluation,
+)
+from .model_evaluation_slice import (
+    ModelEvaluationSlice,
+)
 from .model_monitoring import (
     ModelMonitoringAlertConfig,
     ModelMonitoringObjectiveConfig,
@@ -343,6 +402,7 @@ from .model_service import (
     GetModelEvaluationRequest,
     GetModelEvaluationSliceRequest,
     GetModelRequest,
+    ImportModelEvaluationRequest,
     ListModelEvaluationSlicesRequest,
     ListModelEvaluationSlicesResponse,
     ListModelEvaluationsRequest,
@@ -385,7 +445,9 @@ from .prediction_service import (
     PredictResponse,
     RawPredictRequest,
 )
-from .specialist_pool import SpecialistPool
+from .specialist_pool import (
+    SpecialistPool,
+)
 from .specialist_pool_service import (
     CreateSpecialistPoolOperationMetadata,
     CreateSpecialistPoolRequest,
@@ -402,7 +464,9 @@ from .study import (
     StudySpec,
     Trial,
 )
-from .tensorboard import Tensorboard
+from .tensorboard import (
+    Tensorboard,
+)
 from .tensorboard_data import (
     Scalar,
     TensorboardBlob,
@@ -411,8 +475,12 @@ from .tensorboard_data import (
     TimeSeriesData,
     TimeSeriesDataPoint,
 )
-from .tensorboard_experiment import TensorboardExperiment
-from .tensorboard_run import TensorboardRun
+from .tensorboard_experiment import (
+    TensorboardExperiment,
+)
+from .tensorboard_run import (
+    TensorboardRun,
+)
 from .tensorboard_service import (
     BatchCreateTensorboardRunsRequest,
     BatchCreateTensorboardRunsResponse,
@@ -457,7 +525,9 @@ from .tensorboard_service import (
     WriteTensorboardRunDataRequest,
     WriteTensorboardRunDataResponse,
 )
-from .tensorboard_time_series import TensorboardTimeSeries
+from .tensorboard_time_series import (
+    TensorboardTimeSeries,
+)
 from .training_pipeline import (
     FilterSplit,
     FractionSplit,
@@ -473,9 +543,15 @@ from .types import (
     Int64Array,
     StringArray,
 )
-from .unmanaged_container_model import UnmanagedContainerModel
-from .user_action_reference import UserActionReference
-from .value import Value
+from .unmanaged_container_model import (
+    UnmanagedContainerModel,
+)
+from .user_action_reference import (
+    UserActionReference,
+)
+from .value import (
+    Value,
+)
 from .vizier_service import (
     AddTrialMeasurementRequest,
     CheckTrialEarlyStoppingStateMetatdata,
@@ -546,6 +622,7 @@ __all__ = (
     "EncryptionSpec",
     "DeployedModel",
     "Endpoint",
+    "PredictRequestResponseLoggingConfig",
     "PrivateEndpoints",
     "CreateEndpointOperationMetadata",
     "CreateEndpointRequest",
@@ -583,6 +660,7 @@ __all__ = (
     "FeatureSelector",
     "IdMatcher",
     "Featurestore",
+    "FeaturestoreMonitoringConfig",
     "FeatureValue",
     "FeatureValueList",
     "ReadFeatureValuesRequest",
@@ -709,6 +787,7 @@ __all__ = (
     "DedicatedResources",
     "DiskSpec",
     "MachineSpec",
+    "NfsMount",
     "ResourcesConsumed",
     "ManualBatchTuningParameters",
     "MetadataSchema",
@@ -791,6 +870,7 @@ __all__ = (
     "GetModelEvaluationRequest",
     "GetModelEvaluationSliceRequest",
     "GetModelRequest",
+    "ImportModelEvaluationRequest",
     "ListModelEvaluationSlicesRequest",
     "ListModelEvaluationSlicesResponse",
     "ListModelEvaluationsRequest",
